#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# notification_dialog.pyw
# 
# the user should give us a notification
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright (C) 2014 AIT Austrian Institute of Technology
# AIT Austrian Institute of Technology GmbH
# Donau-City-Strasse 1 | 1220 Vienna | Austria
# http://www.ait.ac.at
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, 
# Boston, MA  02110-1301, USA.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_NotificationDialog import Ui_NotificationDialog 
from about_dialog import AboutDialog


# ------------------------------------------------------------
# code


class NotificationDialog(QtGui.QDialog):

    """A dialog for letting the user pass on a user/notification combo"""

    def __init__(self, caption = 'OpenSecurity Notification', message = 'This is a notification from the OpenSecurity System.'):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_NotificationDialog()
        self.ui.setupUi(self)
        self.setWindowTitle(caption)

        # local members
        self._about_dialog = AboutDialog()

        # connectors
        self.ui.lblMessage.setText(message)
        self.ui.btnAbout.clicked.connect(self.clicked_about)
        self.ui.btnOk.clicked.connect(self.accept)

        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
 

    def clicked_about(self):

        """About button has been clicked."""
        self._about_dialog.show()


    def clicked_ok(self):
        
        """Ok button has been clicked."""
        sys.stdout.write('{ ')
        sys.stdout.write('\'notification\': \'')
        sys.stdout.write(self.ui.edtNotification.text())
        sys.stdout.write('\' ')
        sys.stdout.write('}\n')
        self.accept()


    def set_user_text(user_text):

        """Set a text to explain which notification we need."""
        self.ui.lblText.setText(user_text)


if __name__ == "__main__":
    a = QtGui.QApplication(sys.argv)
    d = NotificationDialog()
    d.show()
    sys.exit(a.exec_())     

